@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -14,19 +14,22 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import sys, os
+import sys
+import os
 import cert_cmd
 import pwd
-from itertools import *
 from calculate.core.server.func import clearDataVars
 
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('cl_core3',sys.modules[__name__])
+
+_ = lambda x: x
+setLocalTranslate('cl_core3', sys.modules[__name__])
 
 _("User must be root")
 _('Failed to import %s')
 _('No module named %s')
 
+
 @clearDataVars
 def main(*args, **keywords):
     if os.path.basename(sys.argv[0]) != 'cl-core':
@@ -49,13 +52,14 @@ def main(*args, **keywords):
         return 0
 
     from calculate.core.datavars import DataVarsCore
+
     ob = DataVarsCore()
     ob.importCore()
 
     # set var env
     if not ob.flIniFile():
         sys.exit(1)
-#    cl_wsdl = ob.Get('cl_wsdl')
+    #    cl_wsdl = ob.Get('cl_wsdl')
     cl_wsdl = ob.Get('cl_wsdl_available')
     data_path = ob.Get('cl_core_data')
     local_data_path = ob.Get('cl_core_local_data')
@@ -76,11 +80,13 @@ def main(*args, **keywords):
     cl_ver = ob.Get('cl_ver')
     log_path_var = ob.Get('cl_log_path')
     cl_core_port = ob.GetInteger('cl_core_port')
+    port = cl_core_port
     file_logger = None
 
     # создать симлинки на команды
     if not args.method and args.create_symlink:
         from func import create_symlink, initialization
+
         initialization(cl_wsdl)
         create_symlink(local_data_path, data_path)
         return 0
@@ -89,21 +95,25 @@ def main(*args, **keywords):
         print cl_ver
         return 0
 
+    log_filename = None
+
     if ob.Get('cl_ebuild_phase') == '' and os.getuid() == 0:
         import logging
         import logging.handlers
 
+        logging.raiseExceptions = 0
+
         log_path = args.log_path if args.log_path else log_path_var
 
         if not os.path.exists(log_path):
             os.makedirs(log_path)
-        LOG_FILENAME = os.path.join(log_path, 'logging_cl_core.out')
+        log_filename = os.path.join(log_path, 'logging_cl_core.out')
         file_logger = logging.getLogger('MyLogger')
         file_logger.setLevel(logging.DEBUG)
 
         # Add the log message handler to the logger
         handler = logging.handlers.RotatingFileHandler(
-                    LOG_FILENAME, maxBytes=10000000, backupCount=3)
+            log_filename, maxBytes=10000000, backupCount=3)
 
         file_logger.addHandler(handler)
 
@@ -116,38 +126,44 @@ def main(*args, **keywords):
         from urllib2 import URLError
 
     from traceback import print_exc
+
     ob.close()
     if not args.method:
         try:
             port = args.port or cl_core_port
             if args.check:
                 import bootstrap
-                bootstrap.check(cert, key, cert_path, data_path, certbase, args)
+
+                bootstrap.check(cert, key)
                 return 0
             if args.bootstrap_user_name:
                 try:
                     pwd.getpwnam(args.bootstrap_user_name)
                 except KeyError:
-                    print _("User %s does not exist")%args.bootstrap_user_name
+                    print _("User %s does not exist") % args.bootstrap_user_name
                     return 1
 
                 import bootstrap
-                bootstrap.init(cert, key, cert_path, data_path, certbase, args, \
+
+                bootstrap.init(cert, key, cert_path, data_path, certbase, args,
                                port, args.bootstrap_user_name)
                 return 0
             if args.revoke_cert_id:
                 cert_cmd.revoke_signed_cert(args.revoke_cert_id, data_path,
                                             cert_path)
                 return 0
-            if args.host or args.gen_root_cert or args.root_host or \
-                                                               args.use_root_cert:
-                cert_cmd.check_server_certificate(cert, key, cert_path, args, port)
+            if (args.host or args.gen_root_cert or args.root_host or
+                    args.use_root_cert):
+                cert_cmd.check_server_certificate(cert, key, cert_path, args,
+                                                  port)
                 return 0
             if args.id_client_req:
-                cert_cmd.sing_req_by_server(args.id_client_req,cert_path,data_path)
+                cert_cmd.sing_req_by_server(args.id_client_req, cert_path,
+                                            data_path)
                 return 0
             if args.Id:
-                cert_cmd.view_cert(args, certbase, data_path, rights, group_rights)
+                cert_cmd.view_cert(args, certbase, data_path, rights,
+                                   group_rights)
                 return 0
             if args.cert_id:
                 cert_cmd.view_signed_cert(args, serv_certbase, data_path)
@@ -163,16 +179,20 @@ def main(*args, **keywords):
                 cert_cmd.del_request(args.id_del_req, args.id_del_client_req,
                                      serv_certbase, certbase, data_path)
                 return 0
-        except URLError, e:
-            if file_logger:
-                fd = open(LOG_FILENAME,'a')
-                file_logger.debug(print_exc(file=fd))
-                fd.close()
-            print e
+        except BaseException as e:
+            from urllib2 import URLError
+            if isinstance(e, URLError) and log_filename:
+                if file_logger:
+                    fd = open(log_filename, 'a')
+                    file_logger.debug(print_exc(file=fd))
+                    fd.close()
+                print e
+            else:
+                raise
     params_list = ["start", "create_symlink", "method",
                    "list_methods"]
     for param in params_list:
-        if hasattr(args,param) and getattr(args,param):
+        if hasattr(args, param) and getattr(args, param):
             break
     else:
         parser.print_help()
@@ -180,58 +200,66 @@ def main(*args, **keywords):
     #####################
     # importing other modules
     from func import initialization
+
     other_mod = initialization(cl_wsdl)
-    #try:
+    # try:
     pack = "calculate.core.server"
     import importlib
-    func_metaclass = importlib.import_module('%s.func_metaclass' %pack)
+
+    func_metaclass = importlib.import_module('%s.func_metaclass' % pack)
 
     other_mod.append(func_metaclass.Func_MetaClass)
 
     from calculate.core.server.baseClass import Basic
+
     other_mod.append(Basic)
     other_mod.append(object)
     # make server metaclass
     if args.method or args.list_methods:
         from local_call import local_method, LocalCall
+
         CombinedServerClass = type("CombinedServerClass",
                                    tuple([LocalCall] + other_mod), {})
         return local_method(CombinedServerClass, args, unknown_args)
 
-    CombinedServerClass = type ("CombinedServerClass", tuple(other_mod), {})
+    CombinedServerClass = type("CombinedServerClass", tuple(other_mod), {})
 
     from server_class import ClApplication, OpenSSLAdapter
-    App = ClApplication([CombinedServerClass],'tns', log = file_logger)
+
+    App = ClApplication([CombinedServerClass], 'tns', log=file_logger)
     tc = App.get_service(CombinedServerClass)
 
     # delete all sid and pid informations file
-    cert_cmd.create_path(data_path, certbase, rights, group_rights,local_data_path)
+    cert_cmd.create_path(data_path, certbase, rights, group_rights,
+                         local_data_path)
 
     # set all path
-    tc.set_paths (data_path, certbase, serv_certbase, rights, group_rights, \
-                sids, pids, sids_pids, sids_file, pids_file, max_sid, \
-                max_pid, cert_path, LOG_FILENAME, cert, key)
+    tc.set_paths(data_path, certbase, serv_certbase, rights, group_rights,
+                 sids, pids, sids_pids, sids_file, pids_file, max_sid,
+                 max_pid, cert_path, log_filename, cert, key)
     # запустить выполнение регулярных задач (мониторинг и т.д.)
     tc.run_tasks()
 
     max_num = 99999999
     from cherrypy.wsgiserver import CherryPyWSGIServer, WSGIPathInfoDispatcher
-    dispatcher = WSGIPathInfoDispatcher( { '' : App } )
-    server = CherryPyWSGIServer(('0.0.0.0', port), dispatcher,\
-    numthreads = 10, max = max_num, request_queue_size = max_num)
 
-    print _("listening to https://0.0.0.0:%d") % (port)
-    print _("wsdl is located at: https://0.0.0.0:%d/?wsdl") %(port)
+    dispatcher = WSGIPathInfoDispatcher({'': App})
+    server = CherryPyWSGIServer(('0.0.0.0', port), dispatcher,
+                                numthreads=10, max=max_num,
+                                request_queue_size=max_num)
+
+    print _("listening to https://0.0.0.0:%d") % port
+    print _("wsdl is located at: https://0.0.0.0:%d/?wsdl") % port
 
     ca_cert = cert_path + "/ca_root.crt"
-    if not os.path.exists (ca_cert):
+    if not os.path.exists(ca_cert):
         ca_cert = None
 
-    sslAdapter = OpenSSLAdapter(cert, key, ca_cert)
+    ssl_adapter = OpenSSLAdapter(cert, key, ca_cert)
 
-    sslAdapter.certbase = certbase
+    ssl_adapter.certbase = certbase
 
-    server.ssl_adapter = sslAdapter
+    server.ssl_adapter = ssl_adapter
     server.certbase = certbase
     server.serv_certbase = serv_certbase
     server.rights = rights
@@ -247,48 +275,48 @@ def main(*args, **keywords):
     server.ssl_private_key = key
     from OpenSSL.SSL import Error as SSLError
     import socket
+
     try:
         if args.pidfile:
             try:
-                open(args.pidfile,"w").write(str(os.getpid()))
+                open(args.pidfile, "w").write(str(os.getpid()))
             except OSError:
-                sys.stderr.write(_("failed to create PID file %s") \
-                                                        %args.pidfile+"\n")
+                sys.stderr.write(_("failed to create PID file %s")
+                                 % args.pidfile + "\n")
                 sys.exit(1)
         # For cleaning of sessions at server reboot
         from clean import clean
         from gen_pid import clear_finished_pids
+
         clean(sids_file, pids_file, sids_pids, sids, pids)
         clear_finished_pids(ob)
         print _("Server started")
         server.start()
-    except KeyboardInterrupt, e:
+    except KeyboardInterrupt:
         try:
             tc.killall()
         except KeyboardInterrupt:
             pass
-        print '\n'+_("Server stopped")
+        print '\n' + _("Server stopped")
         server.stop()
         sys.exit(0)
     except socket.error, e:
         if e.message == "No socket could be created":
             print _("No socket could be created")
-            print _('Port %d already in use') %port
+            print _('Port %d already in use') % port
         else:
             if file_logger:
-                fd = open(LOG_FILENAME,'a')
+                fd = open(log_filename, 'a')
                 file_logger.debug(print_exc(file=fd))
                 fd.close()
             print e
-    except SSLError, e:
-        print '\n',_('Server certificate not found')#, e
+    except SSLError:
+        print '\n', _('Server certificate not found')  # , e
         print _("use cl-core with option --gen-cert-by HOST "
                 "(--get-cert-from HOST) or --use-root-as-server)")
-    except KeyboardInterrupt:
-            pass
-    except Exception, e:
+    except Exception:
         if file_logger:
-            fd = open(LOG_FILENAME,'a')
+            fd = open(log_filename, 'a')
             file_logger.debug(print_exc(file=fd))
             fd.close()
 
