@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,13 +14,18 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import os, glob, sys
-import time, datetime
+import os
+import glob
+import sys
+import time
+import datetime
 import pickle
 from calculate.core.datavars import DataVarsCore
-from calculate.lib.utils.files import listDirectory
+from calculate.core.server.core_interfaces import CoreServiceInterface
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('cl_core3',sys.modules[__name__])
+
+_ = lambda x: x
+setLocalTranslate('cl_core3', sys.modules[__name__])
 
 
 def clean(sid_file, pid_file, sid_pid, sids_dir, pids_dir):
@@ -42,7 +47,8 @@ def clean(sid_file, pid_file, sid_pid, sids_dir, pids_dir):
                 except OSError:
                     pass
 
-class CoreWsdl:
+
+class CoreWsdl(CoreServiceInterface):
     # watch for process
     def watcher_pid_proc(self, sid, pid):
         period = 2
@@ -52,34 +58,31 @@ class CoreWsdl:
             while self.glob_process_dict[pid]['status'] == 1:
                 # frequency check
                 time.sleep(period)
-                
+
             self._delete_pid(sid, pid)
-        except IOError:
-            print 'Except IOError'
+        except IOError as e:
+            print 'Except IOError', str(e)
         except Exception:
-            print _("PID %d watcher error") %pid
+            print _("PID %d watcher error") % pid
             try:
                 self._delete_pid(sid, pid)
-            except:
+            except Exception:
                 pass
             time.sleep(0.1)
 
     def _delete_pid(self, sid, pid):
         while len(self.glob_frame_list[pid]) > \
-                  self.glob_process_dict[pid]['counter']:
+                self.glob_process_dict[pid]['counter']:
             time.sleep(1)
         methodname = self.glob_process_dict[pid]['method_name']
         if methodname:
             self.clear_cache(sid, methodname)
         self.del_pid(pid)
         self.del_pid_from_sid_pid(pid)
-            
-def monitor(certbase, SID_FILE):
+
+
+def monitor(certbase, sid_file):
     """ function to delete old session """
-    # set default
-    period = 180
-    sid_live = 240
-#    cert_live = 10080
     # Get value of period and lifetime session from DataVars
     try:
         ob = DataVarsCore()
@@ -93,74 +96,74 @@ def monitor(certbase, SID_FILE):
         print _("Variable cl_core_monitor_period or cl_core_sid_live not "
                 "found")
         raise
-        return 1
     # Check lifetime. if necessary, remove
     while True:
         # check session
         try:
-            SID_FILE_T = SID_FILE + '_temp'
-            fd = open(SID_FILE, 'r')
-            ft = open(SID_FILE_T, 'w')
+            sid_file_t = sid_file + '_temp'
+            fd = open(sid_file, 'r')
+            ft = open(sid_file_t, 'w')
             while 1:
                 try:
                     # read all on one record
                     list_sid = pickle.load(fd)
-                except:
+                except (EOFError, KeyError, IOError):
                     break
                 # how time exists session
                 delta = datetime.datetime.now() - list_sid[2]
                 # if not outdated, then leave
-                if (delta.seconds < sid_live * 60):
+                if delta.seconds < sid_live * 60:
                     pickle.dump(list_sid, ft)
             fd.close()
             ft.close()
-            
+
             # copy all from temp file
-            ft = open(SID_FILE_T, 'rb')
-            fd = open(SID_FILE, 'wb')
+            ft = open(sid_file_t, 'rb')
+            fd = open(sid_file, 'wb')
             ft.seek(0)
             fd.write(ft.read())
             ft.close()
             fd.close()
-            
+
             # Delete temp file
-            os.unlink(SID_FILE_T)
-        except:
+            os.unlink(sid_file_t)
+        except (IOError, OSError):
             return 1
-        
+
         # Частота проверки
         time.sleep(60 * period)
 
+
 # check client's presence
-def sid_monitor(SID_FILE, SIDS_DIR, base_obj):
+def sid_monitor(sid_fn, sids_dn, base_obj):
     # check interval
     period = 21
     while True:
         try:
             sids = []
             # create, if file not exists
-            if not os.path.exists(SID_FILE):
-                temp = open(SID_FILE, 'w')
+            if not os.path.exists(sid_fn):
+                temp = open(sid_fn, 'w')
                 temp.close()
-            fd = open(SID_FILE, 'r')
+            fd = open(sid_fn, 'r')
             while 1:
                 try:
                     # read all on one record
                     list_sid = pickle.load(fd)
-                except:
+                except (EOFError, KeyError, IOError):
                     break
                 # add session id in sesession list
                 sids.append(list_sid[0])
             fd.close()
-        except:
+        except (IOError, OSError):
             print _("Error reading SID files")
             return
-        
+
         try:
             # for each session
             for filename in sids:
                 # find file this session
-                sid_path = SIDS_DIR + "/%d.sid"%filename
+                sid_path = sids_dn + "/%d.sid" % filename
                 with base_obj.sid_locker:
                     if os.path.isfile(sid_path):
                         with open(sid_path) as fd:
@@ -179,7 +182,7 @@ def sid_monitor(SID_FILE, SIDS_DIR, base_obj):
                                 sid_inf[1] += 1
                                 pickle.dump(sid_inf, ft)
                                 ft.close()
-        except:
+        except (IOError, OSError, KeyError):
             pass
         # check period
         time.sleep(period)
