@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -14,15 +14,19 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import os, pickle, threading
+import os
+import pickle
+import threading
 from os import path
 import random
+from calculate.core.server.core_interfaces import CoreServiceInterface
 from calculate.lib.utils.files import listDirectory, readFile, readLinesFile
 from calculate.lib.utils.tools import ignore
 import socket
 
 from cert_cmd import find_cert_id
 
+
 class ProcessStatus:
     SuccessFinished = 0
     Worked = 1
@@ -30,10 +34,12 @@ class ProcessStatus:
     NotFound = 3
     Paused = 4
 
+
 class ProcessMode:
     CoreDaemon = "core"
     LocalCall = "local"
 
+
 def get_symlink_commands():
     """
     Получить список команд утилит
@@ -42,6 +48,9 @@ def get_symlink_commands():
     for line in readLinesFile(symlinks):
         yield line.strip()
     yield "/usr/sbin/cl-core"
+    yield "/usr/sbin/cl-update"
+    yield "/usr/sbin/cl-core-patch"
+
 
 def search_worked_process(method_name, clVars,
                           statuses=(ProcessStatus.Worked,)):
@@ -70,10 +79,32 @@ def search_worked_process(method_name, clVars,
 
     return list(generator())
 
+
+worked_filter = lambda x: x['status'] == ProcessStatus.Worked
+
+
+def search_worked_process2(clVars, filter_func=lambda x: True,
+                           status_filter=worked_filter):
+    pids = clVars.Get('core.cl_core_pids_path')
+    for pidfile in listDirectory(pids, fullPath=True):
+        try:
+            status = pickle.load(open(pidfile))
+            if status_filter(status) and filter_func(status):
+                pid_path = path.join("/proc", str(status['os_pid']))
+                if path.exists(pid_path):
+                    cmdline = readFile(path.join(pid_path, "cmdline"))
+                    if cmdline and any(x in cmdline
+                                       for x in get_symlink_commands()):
+                        yield status['os_pid']
+        except (socket.error, ValueError, KeyError, EOFError, OSError) as e:
+            pass
+
+
 def get_pid_info(clVars, statuses=(ProcessStatus.Worked,)):
     """
     Получить информацию о процессах
     """
+
     def generator():
         pids = clVars.Get('core.cl_core_pids_path')
         for pidfile in listDirectory(pids, fullPath=True):
@@ -87,11 +118,11 @@ def get_pid_info(clVars, statuses=(ProcessStatus.Worked,)):
 
     return list(generator())
 
-    #try:
+    # try:
     #    pidfile = path.join(pids,str(pid))
     #    status = pickle.load(open(pidfile))
     #    return status
-    #except (socket.error, ValueError, IOError, KeyError, EOFError, OSError):
+    # except (socket.error, ValueError, IOError, KeyError, EOFError, OSError):
     #    return None
 
 
@@ -112,7 +143,7 @@ def clear_finished_pids(clVars):
 
 
 # process management
-class CoreWsdl():
+class CoreWsdl(CoreServiceInterface):
     # delete process id from list process
     def del_pid(self, pid):
         try:
@@ -130,7 +161,7 @@ class CoreWsdl():
             # write all in file
             fd = open(self.pids_file, 'w')
             fd.write('\n'.join(rst))
-            fd.write('\n') # with join we lose the last newline char
+            fd.write('\n')  # with join we lose the last newline char
             fd.close()
             self.glob_process_dict.pop(pid)
             self.glob_progress_dict.pop(pid)
@@ -177,16 +208,12 @@ class CoreWsdl():
 
     # issue new pid for created process
     def gen_pid(self):
-        # flag = 1 - exists, 0 - missing in PID_FILE
-        flag = 1
-        # while exists generation new process id
-        while flag == 1:
-            new_pid = random.randint(1,self.max_pid)
-            # find in file
-            flag = self.find_pid_in_file(new_pid)
-        # add new process id in list 
-        self.add_pid_in_file(new_pid)
-        return new_pid
+        while True:
+            new_pid = random.randint(1, self.max_pid)
+            # flag = 1 - exists, 0 - missing in PID_FILE
+            if self.find_pid_in_file(new_pid) == 0:
+                self.add_pid_in_file(new_pid)
+                return new_pid
 
     def check_sid_cert(self, sid):
         curThread = threading.currentThread()
@@ -202,8 +229,8 @@ class CoreWsdl():
         # create, if file not exists
         if not os.path.exists(self.sids_file):
             return 0
-#            temp = open(self.sids_file, 'w')
-#            temp.close()
+        #            temp = open(self.sids_file, 'w')
+        #            temp.close()
         fd = open(self.sids_file, 'r')
         while 1:
             try:
@@ -221,7 +248,7 @@ class CoreWsdl():
         # if validation fails
         return flag
 
-    def serv_pid_kill(self, pid, sid, certbase):
+    def serv_pid_kill(self, pid, sid):
         """ Set flag to complete the process """
         check_sid = self.check_sid_cert(sid)
         if not check_sid:
@@ -229,7 +256,7 @@ class CoreWsdl():
 
         # write complete flag (pid_list[6] = 1) in process file
         if not os.path.exists(self.pids):
-            os.system('mkdir %s' %self.pids)
+            os.mkdir(self.pids)
         if not self.process_pid.has_key(pid):
             return 3
         meth = self.process_pid[pid]
@@ -237,6 +264,6 @@ class CoreWsdl():
             try:
                 os.kill(meth.pid, 2)
             except OSError, e:
-                print 'No such process %d' %meth.pid, e
+                print 'No such process %d' % meth.pid, e
                 return 1
-        return 0
\ No newline at end of file
+        return 0
