@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2012-2014 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -37,24 +37,28 @@ from calculate.core.server.loaded_methods import LoadedMethods
 from calculate.core.result_viewer_gui import ProgressGui, ErrorGui, WarningGui
 from gen_pid import ProcessStatus
 
-from methods_func import get_method_argparser, collect_object, \
-    check_result_msg, get_param_pwd, _print, display_error
+from methods_func import (get_method_argparser, collect_object,
+                          check_result_msg, get_param_pwd, _print,
+                          display_error)
 from api_types import ViewInfo
 from cert_cmd import parse
-from methods_func import getErrorOnParam, GotErrorField
+from methods_func import GotErrorField
 from func import shortTraceback, CommonMethods, CommonLink
 
-
+_ = lambda x: x
 setLocalTranslate('cl_core3', sys.modules[__name__])
-from itertools import cycle, izip, ifilter
-import time
+from itertools import izip, ifilter
 
 
 class LocalCall(object):
     method_status = ProcessStatus.NotFound
+    no_progress = None
+    gui_progress = None
+    gui_warning = None
+    no_questions = None
 
-    def startprocess(self, sid, target=None, method=None, method_name=None, \
-                     auto_delete=False, args_proc={}):
+    def startprocess(self, sid, target=None, method=None, method_name=None,
+                     auto_delete=False, args_proc=()):
         """ start process """
         if "LANG" in os.environ:
             curThread = threading.currentThread()
@@ -122,6 +126,13 @@ class LocalCall(object):
             # пропустить создание файла если идет сборка пакета
             if self.clVars.Get('cl_ebuild_phase'):
                 return
+            build_id = ""
+            try:
+                from calculate.builder.variables.action import Actions
+                if self.clVars.Get('cl_action') in Actions.All:
+                    build_id = self.clVars.Get('builder.cl_builder_id')
+            except Exception:
+                pass
             if not os.path.exists(pids):
                 makeDirectory(pids)
             pid_file = path.join(pids, '%d.pid' % pid)
@@ -130,7 +141,8 @@ class LocalCall(object):
                     d = {'name': self.method_name,
                          'mode': ProcessMode.LocalCall,
                          'os_pid': pid,
-                         'status': self.method_status}
+                         'status': self.method_status,
+                         'id': build_id}
                     pickle.dump(d, f)
             except (IOError, OSError) as e:
                 print str(e)
@@ -196,7 +208,7 @@ def local_method(metaclass, args, unknown_args):
             return 1
         try:
             method_parser = get_method_argparser(view, args, cl_core=True)
-        except Exception as e:
+        except Exception:
             #import traceback
             #for i in apply(traceback.format_exception, sys.exc_info()):
             #    sys.stderr.write(i)
@@ -216,7 +228,7 @@ def local_method(metaclass, args, unknown_args):
             colorPrint.printERROR(_('Manually interrupted'))
         except (GotErrorField,) as e:
             pass
-        except Exception as e:
+        except Exception:
             colorPrint.printERROR(shortTraceback(*sys.exc_info()))
             pass
         #            print 'Error: ', e
@@ -254,7 +266,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
         metaObject.no_questions = no_questions
     except SystemExit as e:
         return 1
-    except Exception as e:
+    except Exception:
         import traceback
 
         for i in apply(traceback.format_exception, sys.exc_info()):
@@ -346,8 +358,8 @@ def call_method(metaObject, args, unknown_args, colorPrint):
 
 def create_param_object(view):
     param_object = type('collect_object', (object,), {})
-    setattr(param_object, 'CheckAll', True)
-    setattr(param_object, '_type_info', {})
+    param_object.CheckAll = True
+    param_object._type_info = {}
     for Group in view.groups:
         if not Group.fields:
             continue
@@ -556,7 +568,7 @@ def print_brief_group(Fields, group_name):
                 display.print_group(group_name)
                 show_group = False
             element.show()
-    except Exception as e:
+    except Exception:
         import traceback
         traceback.print_exc()
         raise
