@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -16,14 +16,18 @@
 
 from soaplib.wsgi import Application
 import re
-import logging, os, OpenSSL
+import logging
+import os
+
 logger = logging.getLogger(__name__)
 from lxml import etree
+from lxml.etree import XMLSyntaxError
 import soaplib
 from soaplib.serializers.exception import Fault
 from soaplib.serializers.primitive import string_encoding
 from soaplib.soap import apply_mtom
-import datetime,pickle
+import datetime
+import pickle
 from loaded_methods import LoadedMethods
 
 # for OpenSSLAdapter
@@ -33,28 +37,37 @@ HTTP_500 = '500 Internal server error'
 HTTP_200 = '200 OK'
 HTTP_405 = '405 Method Not Allowed'
 HTTP_403 = '403 Forbidden'
-not_log_list = ['post_server_request', 'post_client_request', 'del_sid', \
-                'get_server_cert', 'get_client_cert', 'get_entire_frame', \
-                'get_crl', 'get_server_host_name', 'get_ca', 'get_table', \
-                'post_cert', 'post_sid', 'active_client', 'list_pid', \
+not_log_list = ['post_server_request', 'post_client_request', 'del_sid',
+                'get_server_cert', 'get_client_cert', 'get_entire_frame',
+                'get_crl', 'get_server_host_name', 'get_ca', 'get_table',
+                'post_cert', 'post_sid', 'active_client', 'list_pid',
                 'get_methods', 'get_frame', 'get_progress', 'pid_info']
 
+
 class ClApplication(Application):
-    def __init__(self, services, tns, name=None, _with_partnerlink=False, \
+    def __init__(self, services, tns, name=None, _with_partnerlink=False,
                  log=None):
-        '''
-        @param A ServiceBase subclass that defines the exposed services.
-        '''
+        """
+        @param services: A ServiceBase subclass that
+                        defines the exposed services.
+        """
         Application.__init__(self, services, tns)
         # add object logging
         self.log = log
+        # access to private members for pycharm
+        self.__get_method_name = getattr(self, "_Application__get_method_name")
+        self.__decode_soap_request = (
+            getattr(self, "_Application__decode_soap_request"))
+        self.__handle_fault = getattr(self, "_Application__handle_fault")
 
     # verification of compliance certificate and session (sid)
-    def check_cert_sid (self, sid, server):
+    def check_cert_sid(self, sid, server):
         import threading
-        curThread = threading.currentThread()
-        cert = curThread.client_cert
+
+        curthread = threading.currentThread()
+        cert = curthread.client_cert
         from cert_cmd import find_cert_id
+
         cert_id = find_cert_id(cert, server.data_path, server.certbase)
         cert_id = int(cert_id)
         if cert_id == 0:
@@ -62,7 +75,7 @@ class ClApplication(Application):
 
         # session file
         if not os.path.exists(server.sids):
-            os.system('mkdir %s' %server.sids)
+            os.system('mkdir %s' % server.sids)
 
         if not os.path.isfile(server.sids_file):
             open(server.sids_file, 'w')
@@ -71,7 +84,7 @@ class ClApplication(Application):
             try:
                 # read all on one record
                 list_sid = pickle.load(fd)
-            except Exception:
+            except (IOError, EOFError, KeyError):
                 break
             # find session id in sids file
             if cert_id == int(list_sid[1]):
@@ -82,81 +95,79 @@ class ClApplication(Application):
     # input parameters - certificate and name method
     def check_rights(self, method_name, req_env, params):
         """ check right client certificate for the method """
+        import OpenSSL
+
         rmethod = re.compile('[{\w]+[}]')
         method_rep = rmethod.findall(method_name)
-        method_name = method_name.replace(method_rep[0],'')
+        method_name = method_name.replace(method_rep[0], '')
         import threading
-        curThread = threading.currentThread()
 
-        cert = curThread.client_cert
-        server_cert = curThread.server.ssl_certificate
-        server_key = curThread.server.ssl_private_key
-        certbase = curThread.server.certbase
-        rights = curThread.server.rights
-        group_rights = curThread.server.group_rights
-        data_path = curThread.server.data_path
-        ip = req_env.get('REMOTE_ADDR')
-        permitted_methods = ['post_server_request', 'post_client_request', \
-                             'get_server_cert', 'get_client_cert', \
+        curthread = threading.currentThread()
+
+        cert = curthread.client_cert
+        server_cert = curthread.server.ssl_certificate
+        server_key = curthread.server.ssl_private_key
+        certbase = curthread.server.certbase
+        rights = curthread.server.rights
+        group_rights = curthread.server.group_rights
+        data_path = curthread.server.data_path
+        permitted_methods = ['post_server_request', 'post_client_request',
+                             'get_server_cert', 'get_client_cert',
                              'get_crl', 'get_server_host_name', 'get_ca']
 
         if method_name in permitted_methods:
             return 1
-        if cert == None:
-            if not method_name in permitted_methods:
-#                self.log.debug('%s NoneCert %s 0 %s' \
-#                        %(datetime.datetime.now().__str__(), ip, method_name))
+        if cert is None:
+            if method_name not in permitted_methods:
                 return 0
-#            self.log.debug('%s NoneCert %s 1 %s' \
-#                        %(datetime.datetime.now().__str__(), ip, method_name))
             return 1
 
         if params:
-            if hasattr (params, 'sid') and (method_name in LoadedMethods.rightsMethods \
-                                    or (method_name.endswith('_view') and \
-                                    method_name[:-5] in LoadedMethods.rightsMethods)):
-                if not self.check_cert_sid(params.sid, curThread.server):
+            if (hasattr(params, 'sid') and
+                    (method_name in LoadedMethods.rightsMethods or
+                     method_name.endswith('_view') and
+                     method_name[:-5] in LoadedMethods.rightsMethods)):
+                if not self.check_cert_sid(params.sid, curthread.server):
                     return 0
 
-        data_server_cert = open(server_cert,'r').read()
-        certobj = OpenSSL.crypto.load_certificate \
-                                  (OpenSSL.SSL.FILETYPE_PEM, data_server_cert)
+        data_server_cert = open(server_cert, 'r').read()
+        certobj = OpenSSL.crypto.load_certificate(
+            OpenSSL.SSL.FILETYPE_PEM, data_server_cert)
 
-        data_server_key = open(server_key,'r').read()
-        Pkey = OpenSSL.crypto.load_privatekey(OpenSSL.SSL.FILETYPE_PEM, \
-                                                    data_server_key, 'qqqq')
+        data_server_key = open(server_key, 'r').read()
+        Pkey = OpenSSL.crypto.load_privatekey(OpenSSL.SSL.FILETYPE_PEM,
+                                              data_server_key, 'qqqq')
         signature = OpenSSL.crypto.sign(Pkey, cert, 'SHA1')
         try:
             OpenSSL.crypto.verify(certobj, signature, cert, 'SHA1')
-        except Exception, e:
+        except Exception as e:
             print e
             return 0
         if method_name == 'cert_add':
             return 0
-        certobj_cl = OpenSSL.crypto.load_certificate \
-                                    (OpenSSL.SSL.FILETYPE_PEM, cert)
+        certobj_cl = OpenSSL.crypto.load_certificate(
+            OpenSSL.SSL.FILETYPE_PEM, cert)
         try:
-            com = certobj_cl.get_extension(certobj_cl.get_extension_count()-1)
+            com = certobj_cl.get_extension(certobj_cl.get_extension_count() - 1)
             groups = com.get_data().split(':')[1]
-        except IndexError as e:
+        except IndexError:
             groups = ""
-        except Exception as e:
+        except Exception:
             return 0
         groups_list = groups.split(',')
-        cert_id = 0
         # open certificates database
         if not os.path.exists(certbase):
-            fc = open(certbase,"w")
+            fc = open(certbase, "w")
             fc.close()
         from cert_cmd import find_cert_id
+
         checked_id = find_cert_id(cert, data_path, certbase)
         cert_id = int(checked_id)
         count = 0
-        flag = 0
         find_flag = False
         # if certificate found
         if cert_id > 0:
-            if not method_name in LoadedMethods.rightsMethods:
+            if method_name not in LoadedMethods.rightsMethods:
                 return 1
 
             # if group = all and not redefined group all
@@ -171,15 +182,15 @@ class ClApplication(Application):
                     if line.split()[0] == 'all':
                         find_flag = True
                         break
-#                if not find_flag:
-#                    return 1
+                    #                if not find_flag:
+                    #                    return 1
 
             for right_param in LoadedMethods.rightsMethods[method_name]:
                 flag = 0
                 try:
                     # check rights
-                    if not os.path.exists (rights):
-                        open(rights,'w')
+                    if not os.path.exists(rights):
+                        open(rights, 'w')
                     with open(rights) as fr:
                         t = fr.read()
                         for line in t.splitlines():
@@ -189,7 +200,7 @@ class ClApplication(Application):
                                 for word in words:
                                     try:
                                         word = int(word)
-                                    except:
+                                    except ValueError:
                                         continue
                                     # compare with certificat number
                                     if cert_id == word:
@@ -199,18 +210,20 @@ class ClApplication(Application):
                                         break
                                     if cert_id == -word:
                                         return 0
-                            if flag: break
+                            if flag:
+                                break
 
-                    if flag: break
+                    if flag:
+                        break
                     # open file with groups rights
-                    if not os.path.exists (group_rights):
-                        open(group_rights,'w')
+                    if not os.path.exists(group_rights):
+                        open(group_rights, 'w')
                     with open(group_rights) as fd:
                         t = fd.read()
                         for line in t.splitlines():
                             if not line:
                                 continue
-                            words = line.split(' ',1)
+                            words = line.split(' ', 1)
                             # first word in line equal name input method
                             if words[0] in groups_list:
                                 methods = words[1].split(',')
@@ -221,25 +234,27 @@ class ClApplication(Application):
                                         count += 1
                                         flag = 1
                                         break
-                            if flag: break
-                except:
+                            if flag:
+                                break
+                except Exception:
                     return 0
-            if count == len (LoadedMethods.rightsMethods[method_name]):
+            if count == len(LoadedMethods.rightsMethods[method_name]):
                 return 1
         if not find_flag and 'all' in groups_list:
             return 1
-        elif method_name in ['post_cert','init_session']:
+        elif method_name in ['post_cert', 'init_session']:
             return 1
         return 0
 
     def create_path(self):
         """ create paths for server files """
         import threading
-        curThread = threading.currentThread()
-        data_path = curThread.server.data_path
-        sids = curThread.server.sids
-        pids = curThread.server.pids
-        cert_path = curThread.server.cert_path
+
+        curthread = threading.currentThread()
+        data_path = curthread.server.data_path
+        sids = curthread.server.sids
+        pids = curthread.server.pids
+        cert_path = curthread.server.cert_path
         if not os.path.exists(sids):
             if not os.path.exists(data_path):
                 os.makedirs(data_path)
@@ -268,22 +283,23 @@ class ClApplication(Application):
         if not os.path.exists(cert_path):
             os.makedirs(cert_path)
 
-
     def _Application__handle_soap_request(self, req_env, start_response, url):
         """
         This function is too big.
         """
+        import OpenSSL
         import threading
-        curThread = threading.currentThread()
-        curThread.REMOTE_ADDR = req_env.get('REMOTE_ADDR')
-        curThread.REMOTE_PORT = req_env.get('REMOTE_PORT')
+
+        curthread = threading.currentThread()
+        curthread.REMOTE_ADDR = req_env.get('REMOTE_ADDR')
+        curthread.REMOTE_PORT = req_env.get('REMOTE_PORT')
         ip = req_env.get('REMOTE_ADDR')
 
         http_resp_headers = {
             'Content-Type': 'text/xml',
             'Content-Length': '0',
         }
-        method_name = None
+        service = None
 
         self.create_path()
         try:
@@ -301,14 +317,12 @@ class ClApplication(Application):
 
             try:
                 service = None
-                soap_req_header, soap_req_payload = \
-                self._Application__decode_soap_request(req_env, body)
+                soap_req_header, soap_req_payload = self.__decode_soap_request(
+                    req_env, body)
                 if not (soap_req_payload is None):
                     self.validate_request(soap_req_payload)
 
-                method_name = \
-                    self._Application__get_method_name \
-                                                (req_env, soap_req_payload)
+                method_name = self.__get_method_name(req_env, soap_req_payload)
                 if method_name is None:
                     resp = "Could not extract method name from the request!"
                     http_resp_headers['Content-Length'] = str(len(resp))
@@ -324,11 +338,13 @@ class ClApplication(Application):
                 if logger.level == logging.DEBUG:
                     try:
                         logger.debug(etree.tostring(etree.fromstring(body),
-                                                           pretty_print=True))
-                    except etree.XMLSyntaxError,e:
+                                                    pretty_print=True))
+                    except XMLSyntaxError as e:
                         logger.debug(body)
-                        raise Fault('Client.XMLSyntax',\
-                                    'Error at line: %d, col: %d' % e.position)
+                        raise Fault('Client.XMLSyntax',
+                                    'Error at line: %d, col: %d'
+                                    # for pycharm
+                                    % getattr(e, "position"))
 
             # retrieve the method descriptor
             descriptor = service.get_method(method_name)
@@ -344,64 +360,65 @@ class ClApplication(Application):
                 params = descriptor.in_message.from_xml(soap_req_payload)
             else:
                 params = [None] * len(descriptor.in_message._type_info)
-
-        #### check_rights
+                # check_rights
             import threading
-            curThread = threading.currentThread()
+
+            curthread = threading.currentThread()
             # check exists client certificate
-            if not hasattr (curThread, 'client_cert'):
-                curThread.client_cert = None
+            if not hasattr(curthread, 'client_cert'):
+                curthread.client_cert = None
             # check rights client certificate for the method
             check = self.check_rights(method_name, req_env, params)
             if not check:
-                if curThread.client_cert:
-                    certobj = OpenSSL.crypto.load_certificate \
-                            (OpenSSL.SSL.FILETYPE_PEM, curThread.client_cert)
+                if curthread.client_cert:
+                    certobj = OpenSSL.crypto.load_certificate(
+                        OpenSSL.SSL.FILETYPE_PEM, curthread.client_cert)
                     finger = certobj.digest('SHA1')
                     if self.log:
-                        self.log.debug('%s %s %s forbidden %s' \
-                            %(datetime.datetime.now().__str__(), finger, ip, \
-                            method_name[5:]))
+                        self.log.debug('%s %s %s forbidden %s'
+                                       % (datetime.datetime.now().__str__(),
+                                          finger, ip,
+                                          method_name[5:]))
                 resp = "Permission denied: " + method_name
                 http_resp_headers['Content-Length'] = str(len(resp))
                 start_response(HTTP_403, http_resp_headers.items())
                 return [resp]
-            if hasattr (params, 'sid'):
-                curThread.lang = service.get_lang(params.sid, method_name)
+            if hasattr(params, 'sid'):
+                curthread.lang = service.get_lang(params.sid, method_name)
                 if "get_methods" in method_name:
-                    with open('/tmp/getlang','a') as f:
-                        f.write(curThread.lang+"\n")
-
-        #### logging
-            if curThread.client_cert:
-                certobj = OpenSSL.crypto.load_certificate \
-                        (OpenSSL.SSL.FILETYPE_PEM, curThread.client_cert)
+                    with open('/tmp/getlang', 'a') as f:
+                        f.write(curthread.lang + "\n")
+                        # logging
+            if curthread.client_cert:
+                certobj = OpenSSL.crypto.load_certificate(
+                    OpenSSL.SSL.FILETYPE_PEM, curthread.client_cert)
                 finger = certobj.digest('SHA1')
-                if not method_name[5:] in not_log_list and \
-                                        not method_name[5:].endswith('_view'):
+                if (not method_name[5:] in not_log_list and
+                        not method_name[5:].endswith('_view')):
                     if self.log:
-                        self.log.debug('%s %s %s allowed %s' \
-                            %(datetime.datetime.now().__str__(), finger, ip, \
-                            method_name[5:]))
+                        self.log.debug('%s %s %s allowed %s'
+                                       % (datetime.datetime.now().__str__(),
+                                          finger, ip,
+                                          method_name[5:]))
 
             # implementation hook
             service.on_method_call(req_env, method_name, params,
-                                                             soap_req_payload)
+                                   soap_req_payload)
 
             # call the method
             result_raw = service.call_wrapper(func, params)
 
             # construct the soap response, and serialize it
             envelope = etree.Element('{%s}Envelope' % soaplib.ns_soap_env,
-                                                          nsmap=soaplib.nsmap)
+                                     nsmap=soaplib.nsmap)
 
             #
             # header
             #
-            soap_header_elt = etree.SubElement(envelope,
-                                           '{%s}Header' % soaplib.ns_soap_env)
+            soap_header_elt = etree.SubElement(
+                envelope, '{%s}Header' % soaplib.ns_soap_env)
 
-            if service.soap_out_header != None:
+            if service.soap_out_header is None:
                 if descriptor.out_header is None:
                     logger.warning("Skipping soap response header as %r "
                                    "method is not published to have a soap "
@@ -420,7 +437,7 @@ class ClApplication(Application):
             # body
             #
             soap_body = etree.SubElement(envelope,
-                                            '{%s}Body' % soaplib.ns_soap_env)
+                                         '{%s}Body' % soaplib.ns_soap_env)
 
             # instantiate the result message
             result_message = descriptor.out_message()
@@ -439,21 +456,21 @@ class ClApplication(Application):
 
             # transform the results into an element
             descriptor.out_message.to_xml(result_message, self.get_tns(),
-                                                                    soap_body)
+                                          soap_body)
             # implementation hook
             service.on_method_return(req_env, result_raw, soap_body,
-                                                            http_resp_headers)
+                                     http_resp_headers)
 
             #
             # misc
             #
             results_str = etree.tostring(envelope, xml_declaration=True,
-                                                     encoding=string_encoding)
+                                         encoding=string_encoding)
 
             if descriptor.mtom:
-                http_resp_headers, results_str = apply_mtom(http_resp_headers,
-                               results_str, descriptor.out_message._type_info,
-                               [result_raw])
+                http_resp_headers, results_str = apply_mtom(
+                    http_resp_headers, results_str,
+                    descriptor.out_message._type_info, [result_raw])
 
             # implementation hook
             self.on_return(req_env, http_resp_headers, results_str)
@@ -463,42 +480,47 @@ class ClApplication(Application):
             start_response(HTTP_200, http_resp_headers.items())
 
             if logger.level == logging.DEBUG:
-                logger.debug('\033[31m'+ "Response" + '\033[0m')
+                logger.debug('\033[31m' + "Response" + '\033[0m')
                 logger.debug(etree.tostring(envelope, xml_declaration=True,
-                                                            pretty_print=True))
+                                            pretty_print=True))
             # return the serialized results
             return [results_str]
 
         # The user issued a Fault, so handle it just like an exception!
-        except Fault, e:
-            return self._Application__handle_fault(req_env, start_response,
-                                                http_resp_headers, service, e)
+        except Fault as e:
+            return self.__handle_fault(req_env, start_response,
+                                       http_resp_headers, service, e)
 
-        except Exception, e:
+        except Exception as e:
             fault = Fault('Server', str(e))
 
-            return self._Application__handle_fault(req_env, start_response,
-                                            http_resp_headers, service, fault)
+            return self.__handle_fault(req_env, start_response,
+                                       http_resp_headers, service, fault)
 
-class OpenSSLAdapter (pyOpenSSLAdapter):
+
+class OpenSSLAdapter(pyOpenSSLAdapter):
     def verify_func(self, connection, x509, errnum, errdepth, ok):
         # get client certificate
+        import OpenSSL
         import threading
-        curThread = threading.currentThread()
+
+        curthread = threading.currentThread()
         if errdepth == 0:
-            curThread.client_cert = OpenSSL.crypto.dump_certificate \
-                                        (OpenSSL.crypto.FILETYPE_PEM, x509)
+            curthread.client_cert = OpenSSL.crypto.dump_certificate(
+                OpenSSL.crypto.FILETYPE_PEM, x509)
         else:
-            curThread.client_cert = None
+            curthread.client_cert = None
         return ok
 
     def get_context(self):
         """Return an SSL.Context from self attributes."""
         # See http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/442473
+        import OpenSSL
+
         c = OpenSSL.SSL.Context(OpenSSL.SSL.TLSv1_2_METHOD)
         c.set_options(OpenSSL.SSL.OP_NO_SSLv2 | OpenSSL.SSL.OP_NO_SSLv3)
 
-        #c.set_passwd_cb(lambda *unused: 'qqqq')
+        # c.set_passwd_cb(lambda *unused: 'qqqq')
         c.use_privatekey_file(self.private_key)
         c.set_verify(OpenSSL.SSL.VERIFY_PEER, self.verify_func)
 
